synapse.api.constants module — Synapse 1.0 documentation

# synapse.api.constants module

Contains constants from the specification.

class `synapse.api.constants.` `EventFormatVersions`

  Bases: `object`

  This is an internal enum for tracking the version of the event format, independently from the room version.

  `V1` = 1
  `V2` = 2

class `synapse.api.constants.` `EventTypes`

  Bases: `object`

  `Aliases` = 'm.room.aliases'
  `CanonicalAlias` = 'm.room.canonical_alias'
  `Create` = 'm.room.create'
  `Encryption` = 'm.room.encryption'
  `GuestAccess` = 'm.room.guest_access'
  `JoinRules` = 'm.room.join_rules'
  `Member` = 'm.room.member'
  `Message` = 'm.room.message'
  `Name` = 'm.room.name'
  `Pinned` = 'm.room.pinned_events'
  `PowerLevels` = 'm.room.power_levels'
  `Redaction` = 'm.room.redaction'
  `RoomAvatar` = 'm.room.avatar'
  `RoomEncryption` = 'm.room.encryption'
  `RoomHistoryVisibility` = 'm.room.history_visibility'
  `ServerACL` = 'm.room.server_acl'
  `ThirdPartyInvite` = 'm.room.third_party_invite'
  `Tombstone` = 'm.room.tombstone'
  `Topic` = 'm.room.topic'

class `synapse.api.constants.` `JoinRules`

  Bases: `object`

  `INVITE` = 'invite'
  `KNOCK` = 'knock'
  `PRIVATE` = 'private'
  `PUBLIC` = 'public'

class `synapse.api.constants.` `LoginType`

  Bases: `object`

  `APPLICATION_SERVICE` = 'm.login.application_service'
  `DUMMY` = 'm.login.dummy'
  `EMAIL_IDENTITY` = 'm.login.email.identity'
  `MSISDN` = 'm.login.msisdn'
  `PASSWORD` = 'm.login.password'
  `RECAPTCHA` = 'm.login.recaptcha'
  `SHARED_SECRET` = 'org.matrix.login.shared_secret'
  `TERMS` = 'm.login.terms'

class `synapse.api.constants.` `Membership`

  Bases: `object`

  Represents the membership states of a user in a room.

  `BAN` = 'ban'
  `INVITE` = 'invite'
  `JOIN` = 'join'
  `KNOCK` = 'knock'
  `LEAVE` = 'leave'
  `LIST` = ('invite', 'join', 'knock', 'leave', 'ban')

class `synapse.api.constants.` `PresenceState`

  Bases: `object`

  Represents the presence state of a user.

  `OFFLINE` = 'offline'
  `ONLINE` = 'online'
  `UNAVAILABLE` = 'unavailable'

class `synapse.api.constants.` `RejectedReason`

  Bases: `object`

  `AUTH_ERROR` = 'auth_error'
  `NOT_ANCESTOR` = 'not_ancestor'
  `REPLACED` = 'replaced'

class `synapse.api.constants.` `RoomCreationPreset`

  Bases: `object`

  `PRIVATE_CHAT` = 'private_chat'
  `PUBLIC_CHAT` = 'public_chat'
  `TRUSTED_PRIVATE_CHAT` = 'trusted_private_chat'

class `synapse.api.constants.` `RoomDisposition`

  Bases: `object`

  `STABLE` = 'stable'
  `UNSTABLE` = 'unstable'

class `synapse.api.constants.` `RoomVersions`

  Bases: `object`

  `STATE_V2_TEST` = 'state-v2-test'
  `V1` = '1'
  `V2` = '2'
  `V3` = '3'

class `synapse.api.constants.` `ThirdPartyEntityKind`

  Bases: `object`

  `LOCATION` = 'location'
  `USER` = 'user'

class `synapse.api.constants.` `UserTypes`

  Bases: `object`

  Allows for user type specific behaviour. With the benefit of hindsight ‘admin’ and ‘guest’ users should also be UserTypes. Normal users are type None

  `ALL_USER_TYPES` = ('support',)
  `SUPPORT` = 'support'